#!/bin/sh
# setup.sh
# This script should be run after the SnortCenter Sensor archive is unpacked, in order
# to setup the various config files

# Find install directory
LANG=
export LANG
cd `dirname $0`
if [ -x /bin/pwd ]; then
	wadir=`/bin/pwd`
else
	wadir=`pwd`;
fi
ver=`cat "$wadir/version"`
clear
echo "***********************************************************************************"
echo "*       Welcome to the SnortCenter Sensor Agent setup script, version $ver        *"
echo "***********************************************************************************"
echo ""

# Only root can run this
id | grep "uid=0(" >/dev/null
if [ $? != "0" ]; then
	uname -a | grep -i CYGWIN >/dev/null
	if [ $? != "0" ]; then
		echo "ERROR: The Sensor Agent install script must be run as root";
		echo "";
		exit 1;
	fi
fi

# Display install directory
echo "Installing Sensor in $wadir ..."
echo ""

# Ask for Sensor Agent config directory
echo "*************************************************************************************"
echo "The Sensor Agent uses separate directories for configuration files and log files."
echo "Unless you want to place them in a other directory, you can just accept the defaults."
echo ""
printf "Config file directory [$wadir/conf]: "
if [ "$config_dir" = "" ]; then
	read config_dir
fi
if [ "$config_dir" = "" ]; then
	config_dir=$wadir/conf
fi
abspath=`echo $config_dir | grep "^/"`
if [ "$abspath" = "" ]; then
	echo "Config directory must be an absolute path"
	echo ""
	exit 2
fi
if [ ! -d $config_dir ]; then
	mkdir -p $config_dir;
	if [ $? != 0 ]; then
		echo "ERROR: Failed to create directory $config_dir"
		echo ""
		exit 2
	fi
fi
if [ -r "$config_dir/config" ]; then
	echo "Found existing sensor configuration in $config_dir"
	echo ""
	upgrading=1
fi

# Check if upgrading from an old version
if [ "$upgrading" = 1 ]; then
	# Get current var path
	var_dir=`cat $config_dir/var-path`

	# Get current perl path
	perl=`cat $config_dir/perl-path`

	# Create temp files directory
	$perl "$wadir/maketemp.pl"
	if [ "$?" != "0" ]; then
		echo "ERROR: Failed to create or check temp files directory /tmp/.snortcenter"
		echo ""
		exit 2
	fi

	# Stop old version
	$config_dir/stop >/dev/null 2>&1

	# Get old os name and version
	os_type=`grep "^os_type=" $config_dir/config | sed -e 's/os_type=//g'`
	os_version=`grep "^os_version=" $config_dir/config | sed -e 's/os_version=//g'`
	real_os_type=`grep "^real_os_type=" $config_dir/config | sed -e 's/real_os_type=//g'`
	real_os_version=`grep "^real_os_version=" $config_dir/config | sed -e 's/real_os_version=//g'`

	# Get old root, host, port, ssl and boot flag
	oldwadir=`grep "^root=" $config_dir/miniserv.conf | sed -e 's/root=//g'`
	host=`grep "^host=" $config_dir/miniserv.conf | sed -e 's/host=//g'`
	port=`grep "^port=" $config_dir/miniserv.conf | sed -e 's/port=//g'`
	ssl=`grep "^ssl=" $config_dir/miniserv.conf | sed -e 's/ssl=//g'`
	atboot=`grep "^atboot=" $config_dir/miniserv.conf | sed -e 's/atboot=//g'`

	# Update miniserv.conf with new root directory and mime types file
	grep -v "^root=" $config_dir/miniserv.conf | grep -v "^listen=" >/tmp/.snortcenter/$$.miniserv.conf
	mv /tmp/.snortcenter/$$.miniserv.conf $config_dir/miniserv.conf
	echo "root=$wadir/cgi" >> $config_dir/miniserv.conf
	grep logout= $config_dir/miniserv.conf >/dev/null
	if [ $? != "0" ]; then
		echo "logout=$config_dir/logout-flag" >> $config_dir/miniserv.conf
	fi
else

	# Ask for log directory
	printf "Log file directory [$wadir/log]: "
	if [ "$var_dir" = "" ]; then
		read var_dir
	fi
	if [ "$var_dir" = "" ]; then
		var_dir=$wadir/log
	fi
	abspath=`echo $var_dir | grep "^/"`
	if [ "$abspath" = "" ]; then
		echo "Log file directory must be an absolute path"
		echo ""
		exit 3
	fi
	if [ "$var_dir" = "/" ]; then
		echo "Log directory cannot be /"
		exit ""
		exit 3
	fi
	if [ ! -d $var_dir ]; then
		mkdir -p $var_dir
		if [ $? != 0 ]; then
			echo "ERROR: Failed to create directory $var_dir"
			echo ""
			exit 3
		fi
	fi
	echo ""

	# Ask where perl is installed
	echo "****************************************************************************************"
	echo "SnortCenter Sensor Agent is written entirely in Perl. Please enter the full path to the"
	echo "Perl 5 interpreter on your system."
	echo ""
	if [ -x /usr/bin/perl ]; then
		perldef=/usr/bin/perl
	elif [ -x /usr/local/bin/perl ]; then
		perldef=/usr/local/bin/perl
	else
		perldef=""
	fi
	if [ "$perl" = "" ]; then
		if [ "$perldef" = "" ]; then
			printf "Full path to perl: "
			read perl
			if [ "$perl" = "" ]; then
				echo "ERROR: No path entered!"
				echo ""
				exit 4
			fi
		else
			printf "Full path to perl (default $perldef): "
			read perl
			if [ "$perl" = "" ]; then
				perl=$perldef
			fi
		fi
	fi
	echo ""

	# Test perl 
	echo "Testing Perl ..."
	if [ ! -x $perl ]; then
		echo "ERROR: Failed to find perl at $perl"
		echo ""
		exit 5
	fi
	$perl -e 'print "foobar\n"' 2>/dev/null | grep foobar >/dev/null
	if [ $? != "0" ]; then
		echo "ERROR: Failed to run test perl script. Maybe $perl is"
		echo "not the perl interpreter, or is not installed properly"
		echo ""
		exit 6
	fi
	$perl -e 'exit ($] < 5.002 ? 1 : 0)'
	if [ $? = "1" ]; then
		echo "ERROR: Detected old perl version. SnortCenter Sensor Agent requires"
		echo "perl 5.002 or better to run"
		echo ""
		exit 7
	fi
	$perl -e 'use Socket; print "foobar\n"' 2>/dev/null | grep foobar >/dev/null
	if [ $? != "0" ]; then
		echo "ERROR: Perl Socket module not installed. Maybe Perl has"
		echo "not been properly installed on your system"
		echo ""
		exit 8
	fi
	$perl -e '$c = crypt("xx", "yy"); exit($c ? 0 : 1)'
	if [ $? != "0" ]; then
		echo "ERROR: Perl crypt function does not work. Maybe Perl has"
		echo "not been properly installed on your system"
		echo ""
		exit 8
	fi
	echo "Perl seems to be installed ok"
	echo ""

	# Ask where Snort is installed
	echo "*********************************************************************************"
	echo "SnortCenter Sensor Agent needs Snort to be installed, 'As if you didn't know :-)'" 
	echo "Please enter the full path to snort binary."
	echo ""
	if [ -x /usr/bin/snort ]; then
		snortdef=/usr/bin/
	elif [ -x /usr/local/bin/snort ]; then
		snortdef=/usr/local/bin/
	else
		snortdef=""
	fi
	if [ "$snortdef" = "" ]; then
		printf "Full path to snort: "
		read snort_path
		if [ "$snort_path" = "" ]; then
			echo "ERROR: No path entered!"
			echo ""
			exit 4
		fi
	else
		printf "Full path to snort (default $snortdef): "
		read snort_path
		if [ "$snort_path" = "" ]; then
			snort_path=$snortdef
		fi
	fi
	if [ -r "$snort_path/snort" ]; then
	    snortver=`$snort_path/snort -V 2>&1 | grep "ersion"`
	    echo ""
	    if [ "$snortver" = "" ]; then
		echo "ERROR: Can't find Snort version $snort_path"
		echo ""
		exit 14
	    else
		echo "Ok, found Snort $snortver"
		echo ""
	    fi
	else
	    echo ""
	    echo "ERROR: Snort not found in $snort_path"
	    echo ""
	    exit 14
	fi
	
	# Create snort config directory
	printf "Snort Rule config file directory [$wadir/rules/]: "
	if [ "$snort_rule_dir" = "" ]; then
		read snort_rule_dir
	fi
	if [ "$snort_rule_dir" = "" ]; then
		snort_rule_dir=$wadir/rules/
	fi
	abspath=`echo $snort_rule_dir | grep "^/"`
	if [ "$abspath" = "" ]; then
		echo "Snort Rule directory must be an absolute path"
		echo ""
		exit 2
	fi
	if [ ! -d $snort_rule_dir ]; then
		mkdir -p $snort_rule_dir;
		if [ $? != 0 ]; then
			echo "ERROR: Failed to create directory $snort_rule_dir"
			echo ""
			exit 2
		fi
	fi
	echo ""
	
	# Create temp files directory
	$perl "$wadir/maketemp.pl"
	if [ "$?" != "0" ]; then
		echo "ERROR: Failed to create or check temp files directory /tmp/.snortcenter"
		echo ""
		exit 2
	fi

	# Ask for operating system type
	echo "***********************************************************************"
	if [ "$os_type" = "" ]; then
		autoos=2
		$perl "$wadir/oschooser.pl" "$wadir/os_list.txt" /tmp/.snortcenter/$$.os $autoos
		if [ $? != 0 ]; then
			exit $?
		fi
		. /tmp/.snortcenter/$$.os
		rm -f /tmp/.snortcenter/$$.os
	fi
	echo "Operating system name:    $real_os_type"
	echo "Operating system version: $real_os_version"
	echo ""

	# Ask for web server port, name and password
	echo "********************************************************************"
	echo "SnortCenter Sensor Agent uses its own password protected web server"
	echo "The setup script needs to know :"
	echo " - What port to run the Sensor Agent on. There must not be another"
	echo "   service already using this port."
	echo " - What ip address to listen on."
	echo " - The login name required to access the Sensor Agent."
	echo " - The password required to access the Sensor Agent."
	echo " - The hostname of this system that the Sensor Agent should use."
	echo " - If the Sensor Agent should use SSL (if your system supports it)."
	echo " - Whether to use ip access control."
	echo " - Whether to start Snortcenter Sensor Agent at boot time."
	echo ""
	printf "Sensor port (default 2525): "
	if [ "$port" = "" ]; then
		read port
		if [ "$port" = "" ]; then
			port=2525
		fi
	fi
	if [ $port -lt 1 ]; then
		echo "ERROR: $port is not a valid port number"
		echo ""
		exit 11
	fi
	if [ $port -gt 65535 ]; then
		echo "ERROR: $port is not a valid port number. Port numbers cannot be"
		echo "       greater than 65535"
		echo ""
		exit 12
	fi
	$perl -e 'use Socket; socket(FOO, PF_INET, SOCK_STREAM, getprotobyname("tcp")); setsockopt(FOO, SOL_SOCKET, SO_REUSEADDR, pack("l", 1)); bind(FOO, sockaddr_in($ARGV[0], INADDR_ANY)) || exit(1); exit(0);' $port
	if [ $? != "0" ]; then
		echo "ERROR: TCP port $port is already in use by another program"
		echo ""
		exit 13
	fi
	printf "\nIf this host has multiple IP addresses,\n"
	printf "the server can be configured to listen on\n"
	printf "only one address (default any): "
	if [ "$bind" = "" ]; then
		read bind
		if [ "$bind" = "any" ]; then
			bind=""
		fi
	fi
	printf "Login name (default admin): "
	if [ "$login" = "" ]; then
		read login
		if [ "$login" = "" ]; then
			login="admin"
		fi
	fi
	echo $login | grep : >/dev/null
	if [ "$?" = "0" ]; then
		echo "ERROR: Username contains a : character"
		echo ""
		exit 14
	fi
	echo $login | grep " " >/dev/null
	if [ "$?" = "0" ]; then
		echo "ERROR: Username contains a space"
		echo ""
		exit 14
	fi
	printf "Login password: "
	if [ "$password" = "" -a "$crypt" = "" ]; then
		stty -echo
		read password
		stty echo
		printf "\n"
		printf "Password again: "
		stty -echo
		read password2
		stty echo
		printf "\n"
		if [ "$password" != "$password2" ]; then
			echo "ERROR: Passwords don't match"
			echo ""
			exit 14
		fi
		echo $password | grep : >/dev/null
		if [ "$?" = "0" ]; then
			echo "ERROR: Password contains a : character"
			echo ""
			exit 14
		fi
	fi
	defhost=`hostname`
	printf "Sensor host name (default $defhost): "
	if [ "$host" = "" ]; then
		read host
		if [ "$host" = "" ]; then
			host=$defhost
		fi
	fi
	if [ "$ssl" = "" ]; then
		ssl=0
		$perl -e 'use Net::SSLeay' >/dev/null 2>/dev/null
		if [ $? = "0" ]; then
			printf "Use SSL (y/n): "
			read sslyn
			if [ "$sslyn" = "y" -o "$sslyn" = "Y" ]; then
				ssl=1
			fi
		else
			echo "The Perl SSLeay library is not installed. SSL not available."
			rm -f core
		fi
	fi

	# Ask for ip access control
	echo ""
	echo "*********************************************************************************************"
	echo "The Sensor Agent can be configured allow access only from certain IP addresses."
	echo "Hostnames (like foo.bar.com) and IP networks (like 10.254.3.0 or 10.254.1.0/255.255.255.128)"
	echo "can also be entered."
	echo "You should limit access to your sensor to trusted addresses like the"
	echo "SnortCenter Management Console, especially if it is accessible from the Internet."
	echo "Otherwise, anyone who guesses your password will have complete control of your system."
	echo "You can enter multiple addresses by typing a space between them like (127.0.0.1 foo.bar.com)"
	echo ""
	printf "Allowed IP addresses (default localhost):"
	if [ "$allow" = "" ]; then
		read allow
		if [ "$allow" = "" ]; then
			allow="localhost"
		fi
	fi
	
	# Ask whether to run at boot time
	if [ "$atboot" = "" ]; then
		initsupp=`grep "^os_support=" "$wadir/init/module.info" | sed -e 's/os_support=//g' | grep $os_type`
		atboot=0
		if [ "$initsupp" != "" ]; then
			printf "Start Sensor at boot time (y/n): "
			read atbootyn
			if [ "$atbootyn" = "y" -o "$atbootyn" = "Y" ]; then
				atboot=1
			fi
		else
			echo "SnortCenter Sensor Agent does not support being started at boot time on your system."
		fi
	fi
	makeboot=$atboot

	# Create sensor config file
	echo $perl > $config_dir/perl-path
	echo $var_dir > $config_dir/var-path
	echo "***********************************************************************"
	echo "Creating Sensor Agent config files.."
	cfile=$config_dir/miniserv.conf
	echo "port=$port" >> $cfile
	echo "bind=$bind" >> $cfile
	echo "root=$wadir/cgi" >> $cfile
	echo "host=$host" >> $cfile
	#echo "mimetypes=$wadir/mime.types" >> $cfile
	echo "addtype_cgi=internal/cgi" >> $cfile
	echo "realm=SnortCenter Sensor" >> $cfile
	echo "logfile=$var_dir/miniserv.log" >> $cfile
	echo "pidfile=$var_dir/miniserv.pid" >> $cfile
	echo "errorlog=$var_dir/miniserv.error" >> $cfile
	echo "logtime=168" >> $cfile
	#echo "ppath=$ppath" >> $cfile
	echo "ssl=$ssl" >> $cfile
	echo "env_SENSOR_CONFIG=$config_dir" >> $cfile
	echo "env_SENSOR_VAR=$var_dir" >> $cfile
	echo "atboot=$atboot" >> $cfile
	echo "logout=$config_dir/logout-flag" >> $cfile
	echo "denyfile=\\.pl\$" >> $cfile
	echo "log=1" >> $cfile
	echo "blockhost_failures=5" >> $cfile
	echo "blockhost_time=60" >> $cfile
	echo "passdelay=1" >> $cfile
	echo "syslog=1" >> $cfile
	if [ "$allow" != "" ]; then
		echo "allow=$allow" >> $cfile
	fi
	echo "session=0" >> $cfile
	ufile=$config_dir/sensor.users
	if [ "$crypt" != "" ]; then
		echo "$login:$crypt:0" > $ufile
	else
		$perl -e 'print "$ARGV[0]:",crypt($ARGV[1], "XX"),":0\n"' "$login" "$password" > $ufile
	fi
	chmod 600 $ufile
	echo "userfile=$ufile" >> $cfile

	kfile=$config_dir/sensor.pem
	openssl version >/dev/null 2>&1
	if [ "$?" = "0" ]; then
		# We can generate a new SSL key for this host
		host=`hostname`
		openssl req -newkey rsa:512 -x509 -nodes -out /tmp/.snortcenter/cert -keyout /tmp/.snortcenter/key -days 1825 >/dev/null 2>&1 <<EOF
.
.
.
SnortCenter Agent
.
*
root@$host
EOF
		if [ "$?" = "0" ]; then
			cat /tmp/.snortcenter/cert /tmp/.snortcenter/key >$kfile
		fi
		rm -f /tmp/.snortcenter/cert /tmp/.snortcenter/key
	fi
	if [ ! -r $kfile ]; then
		# Fall back to the built-in key
		cp "$wadir/sensor.pem" $kfile
	fi
	chmod 600 $kfile
	echo "keyfile=$config_dir/sensor.pem" >> $cfile

	chmod 600 $cfile
	echo "..done"
	echo ""

#	echo "Creating access control file.."
#	afile=$config_dir/webmin.acl
#	rm -f $afile
#	echo "$login: $allmods" >> $afile
#	chmod 600 $afile
#	echo "..done"
#	echo ""

fi

if [ "$noperlpath" = "" ]; then
	echo "Inserting path to perl into scripts.."
	(find "$wadir" -name '*.cgi' -print ; find "$wadir" -name '*.pl' -print) | $perl "$wadir/perlpath.pl" $perl -
	echo "..done"
	echo ""
fi

echo "Creating start and stop scripts.."
rm -f $config_dir/stop $config_dir/start
echo "#!/bin/sh" >>$config_dir/start
echo "echo Starting SnortCenter Sensor Agent server in $wadir" >>$config_dir/start
echo "trap '' 1" >>$config_dir/start
echo "LANG=" >>$config_dir/start
echo "export LANG" >>$config_dir/start
uname -a | grep -i 'HP/*UX' >/dev/null
if [ $? = "0" ]; then
	echo "exec '$wadir/miniserv.pl' $config_dir/miniserv.conf &" >>$config_dir/start
else
	echo "exec '$wadir/miniserv.pl' $config_dir/miniserv.conf" >>$config_dir/start
fi

echo "#!/bin/sh" >>$config_dir/stop
echo "echo Stopping SnortCenter Sensor Agent server in $wadir" >>$config_dir/stop
echo "pidfile=\`grep \"^pidfile=\" $config_dir/miniserv.conf | sed -e 's/pidfile=//g'\`" >>$config_dir/stop
echo "kill \`cat \$pidfile\`" >>$config_dir/stop
chmod 755 $config_dir/start $config_dir/stop
echo "..done"
echo ""

if [ "$upgrading" = 1 ]; then
	echo "Updating config files.."
else
	echo "Copying config files.."
fi

#$perl $wadir/copyconfig.pl $os_type $os_version $wadir $config_dir "" $allmods
$perl $wadir/copyconfig.pl $os_type $os_version $wadir $config_dir "" "init" "inittab"
if [ "$upgrading" != 1 ]; then
	# Store the OS and version
	echo "os_type=$os_type" >> $config_dir/config
	echo "os_version=$os_version" >> $config_dir/config
	echo "real_os_type=$real_os_type" >> $config_dir/config
	echo "real_os_version=$real_os_version" >> $config_dir/config
	echo "snort_path=$snort_path" >> $config_dir/config
	echo "snort_rule_path=$snort_rule_dir" >> $config_dir/config
	if [ -r /etc/system.cnf ]; then
		# Found a caldera system config file .. get the language
		source /etc/system.cnf
		if [ "$CONF_LST_LANG" = "us" ]; then
			CONF_LST_LANG=en
		elif [ "$CONF_LST_LANG" = "uk" ]; then
			CONF_LST_LANG=en
		fi
		grep "lang=$CONF_LST_LANG," $wadir/lang_list.txt >/dev/null 2>&1
		if [ "$?" = 0 ]; then
			echo "lang=$CONF_LST_LANG" >> $config_dir/config
		fi
	fi
else
	# one-off hack to set log variable in config from miniserv.conf
	grep log= $config_dir/config >/dev/null
	if [ "$?" = "1" ]; then
		grep log= $config_dir/miniserv.conf >> $config_dir/config
		grep logtime= $config_dir/miniserv.conf >> $config_dir/config
		grep logclear= $config_dir/miniserv.conf >> $config_dir/config
	fi
fi
echo $ver > $config_dir/version
echo "..done"
echo ""

# Set passwd_ fields in miniserv.conf from global config
#grep passwd_file= $config_dir/miniserv.conf >/dev/null
#if [ "$?" != "0" ]; then
#	grep passwd_file= $config_dir/config >> $config_dir/miniserv.conf
#	grep passwd_uindex= $config_dir/config >> $config_dir/miniserv.conf
#	grep passwd_pindex= $config_dir/config >> $config_dir/miniserv.conf
#fi

#if [ "$theme" = "" ]; then
#	theme=`cat $wadir/defaulttheme 2>/dev/null`
#fi
#oldthemeline=`grep "^theme=" $config_dir/config`
#oldtheme=`echo $oldthemeline | sed -e 's/theme=//g'`
#if [ "$theme" != "" ] && [ "$oldthemeline" = "" ] && [ -d $wadir/$theme ]; then
	# Set a special theme if none was set before
#	echo "theme=$theme" >> $config_dir/config
#	echo "preroot=$theme" >> $config_dir/miniserv.conf
#fi

if [ "$makeboot" = "1" ]; then
	echo "Configuring SnortCenter Sensor Agent to start at boot time.."
	(cd "$wadir/init" ; SENSOR_CONFIG=$config_dir SENSOR_VAR=$var_dir "$wadir/init/atboot.pl")
	echo "..done"
	echo ""
fi

if [ "$nouninstall" = "" ]; then
	echo "Creating uninstall script $config_dir/uninstall.sh .."
	cat >$config_dir/uninstall.sh <<EOF
#!/bin/sh
printf "Are you sure you want to uninstall SnortCenter Sensor Agent? (y/n) : "
read answer
printf "\n"
if [ "\$answer" = "y" ]; then
	$config_dir/stop
	if [ "$atboot" = "1" ]; then
		(cd $wadir/init ; SENSOR_CONFIG=$config_dir SENSOR_VAR=$var_dir $wadir/init/delboot.pl)
	fi
	echo "Deleting $wadir .."
	rm -rf $wadir
	echo "Deleting $config_dir .."
	rm -rf $config_dir
	echo "Done!"
fi
EOF
	chmod +x $config_dir/uninstall.sh
	echo "..done"
	echo ""
fi

echo "Changing ownership and permissions .."
chown -R root:bin $config_dir
chmod -R og-rw $config_dir
chmod 755 $config_dir/sendmail/config >/dev/null 2>&1
chmod 755 $config_dir/sendmail/autoreply.pl >/dev/null 2>&1
if [ "$nochown" = "" ]; then
	chown -R root:bin $wadir
	#chmod -R og-rwx $wadir
fi
if [ $var_dir != "/var" ]; then
	chown -R root:bin $var_dir
	chmod -R og-rwx $var_dir
fi
echo "..done"
echo ""

if [ "$nostart" = "" ]; then
	echo "Attempting to start Sensor Agent.."
	$config_dir/start
	if [ $? != "0" ]; then
		echo "ERROR: Failed to start Sensor Agent!"
		echo ""
		exit 14
	fi
	echo "..done"
	echo ""

	echo "**********************************************************************************"
	echo "SnortCenter Sensor Agent has been installed and started successfully."
	echo "You can now create and configure the sensor in the SnortCenter Management Console."
	echo "Or use your webbrowser to go to"
	echo ""
	if [ "$ssl" = "1" ]; then
		echo "  https://$host:$port/"
	else
		echo "  http://$host:$port/"
	fi
	echo ""
	echo "and login with the name and password you entered previously."
	echo ""
	if [ "$ssl" = "1" ]; then
		echo "Because the Sensor Agent uses SSL for encryption only, the certificate"
		echo "it uses is not signed by one of the recognized CAs such as Verisign."
		echo "When you first connect to the Sensor Agent, your browser will ask you if"
		echo "you want to accept the certificate presented, as it does not recognize the CA."
		echo "Say yes."
		echo ""
	fi
fi

if [ "$oldwadir" != "$wadir/cgi" -a "$upgrading" = 1 ]; then
	echo "The directory from the previous version of the SnortCenter Sensor Agent"
	echo "   $oldwadir"
	echo "Can now be safely deleted to free up disk space."
	echo ""
fi

